@@ -15,7 +15,6 @@ from is_core.generic_views.table_views import TableView
 from is_core.main import UIRESTModelISCore
 from is_core.utils import render_model_objects_with_link, render_model_object_with_link
 from is_core.utils.decorators import short_description
-from is_core.rest.paginators import CursorBasedPaginator
 
 from security.config import settings
 from security.models import CommandLog, InputLoggedRequest, OutputLoggedRequest, CeleryTaskLog, CeleryTaskRunLog
@@ -38,25 +37,25 @@ def display_related_objects(request, related_objects):
     )
 
 
-def get_content_type_of_parent_related_classes():
+def get_content_type_pks_of_parent_related_classes():
     return {
-        ContentType.objects.get_for_model(model_class)
+        ContentType.objects.get_for_model(model_class).pk
         for model_class in (CommandLog, InputLoggedRequest, OutputLoggedRequest, CeleryTaskLog, CeleryTaskRunLog)
     }
 
 
-class DisplayRelatedObjectsMixin:
+class SecurityISCoreMixin:
 
     @short_description(_('related objects'))
     def display_related_objects(self, obj, request):
         return display_related_objects(
-            request, obj.related_objects.exclude(object_ct__in=get_content_type_of_parent_related_classes())
+            request, obj.related_objects.exclude(object_ct_id__in=get_content_type_pks_of_parent_related_classes())
         )
 
     @short_description(_('source'))
     def display_source(self, obj, request):
         return display_related_objects(
-            request, obj.related_objects.filter(object_ct__in=get_content_type_of_parent_related_classes())
+            request, obj.related_objects.filter(object_ct_id__in=get_content_type_pks_of_parent_related_classes())
         )
 
     @short_description(_('raised output logged requests'))
@@ -65,7 +64,7 @@ class DisplayRelatedObjectsMixin:
             request,
             OutputLoggedRequest.objects.filter(
                 related_objects__object_id=obj.pk,
-                related_objects__object_ct=ContentType.objects.get_for_model(obj)
+                related_objects__object_ct_id=ContentType.objects.get_for_model(obj).pk
             )
         )
 
@@ -75,7 +74,7 @@ class DisplayRelatedObjectsMixin:
             request,
             CommandLog.objects.filter(
                 related_objects__object_id=obj.pk,
-                related_objects__object_ct=ContentType.objects.get_for_model(obj)
+                related_objects__object_ct_id=ContentType.objects.get_for_model(obj).pk
             )
         )
 
@@ -85,12 +84,12 @@ class DisplayRelatedObjectsMixin:
             request,
             CeleryTaskLog.objects.filter(
                 related_objects__object_id=obj.pk,
-                related_objects__object_ct=ContentType.objects.get_for_model(obj)
+                related_objects__object_ct_id=ContentType.objects.get_for_model(obj).pk
             )
         )
 
 
-class RequestsLogISCore(DisplayRelatedObjectsMixin, UIRESTModelISCore):
+class RequestsLogISCore(SecurityISCoreMixin, UIRESTModelISCore):
 
     abstract = True
 
@@ -183,7 +182,7 @@ class OutputRequestsLogISCore(RequestsLogISCore):
     )
 
 
-class CommandLogISCore(DisplayRelatedObjectsMixin, UIRESTModelISCore):
+class CommandLogISCore(SecurityISCoreMixin, UIRESTModelISCore):
 
     model = CommandLog
 
@@ -229,7 +228,7 @@ class CeleryTaskLogTableView(CeleryTaskLogTabs, TableView):
     pass
 
 
-class CeleryTaskRunLogISCore(DisplayRelatedObjectsMixin, UIRESTModelISCore):
+class CeleryTaskRunLogISCore(SecurityISCoreMixin, UIRESTModelISCore):
 
     model = CeleryTaskRunLog
 
@@ -284,7 +283,7 @@ class CeleryTaskRunLogInlineTableView(InlineTableView):
         }
 
 
-class CeleryTaskLogISCore(DisplayRelatedObjectsMixin, UIRESTModelISCore):
+class CeleryTaskLogISCore(SecurityISCoreMixin, UIRESTModelISCore):
 
     model = CeleryTaskLog
 
